@@ -16,7 +16,6 @@ import subprocess
 import os
 import sys
 import time
-import calendar
 import datetime
 import glob
 import re
@@ -26,8 +25,6 @@ import tempfile
 import shutil
 import locale
 
-from gi.repository import Gio, GLib
-
 from apport.packaging_impl import impl as packaging
 
 import apport
@@ -132,7 +129,7 @@ def attach_conffiles(report, package, conffiles=None, ui=None):
             continue
 
         key = 'modified.conffile.' + path_to_key(path)
-        if contents == '[deleted]':
+        if type(contents) == str and (contents == '[deleted]' or contents.startswith('[inaccessible')):
             report[key] = contents
             continue
 
@@ -164,6 +161,45 @@ def attach_upstart_overrides(report, package):
             attach_file_if_exists(report, override, key)
 
 
+def attach_upstart_logs(report, package):
+    '''Attach information about a package's session upstart logs'''
+
+    try:
+        files = apport.packaging.get_files(package)
+    except ValueError:
+        return
+
+    for f in files:
+        if not os.path.exists(f):
+            continue
+        if f.startswith('/usr/share/upstart/sessions/'):
+            log = os.path.basename(f).replace('.conf', '.log')
+            key = 'upstart.' + log
+            try:
+                log = os.path.join(os.environ['XDG_CACHE_HOME'], 'upstart', log)
+            except KeyError:
+                try:
+                    log = os.path.join(os.environ['HOME'], '.cache', 'upstart', log)
+                except KeyError:
+                    continue
+
+            attach_file_if_exists(report, log, key)
+
+        if f.startswith('/usr/share/applications/') and f.endswith('.desktop'):
+            desktopname = os.path.splitext(os.path.basename(f))[0]
+            key = 'upstart.application.' + desktopname
+            log = 'application-%s.log' % desktopname
+            try:
+                log = os.path.join(os.environ['XDG_CACHE_HOME'], 'upstart', log)
+            except KeyError:
+                try:
+                    log = os.path.join(os.environ['HOME'], '.cache', 'upstart', log)
+                except KeyError:
+                    continue
+
+            attach_file_if_exists(report, log, key)
+
+
 def attach_dmesg(report):
     '''Attach information from the kernel ring buffer (dmesg).
 
@@ -834,45 +870,35 @@ def in_session_of_problem(report):
     This can be used to determine if e. g. ~/.xsession-errors is relevant and
     should be attached.
 
-    Return None if this cannot be determined due to not being able to talk to
-    ConsoleKit.
+    Return None if this cannot be determined.
     '''
     # report time is in local TZ
     orig_ctime = locale.getlocale(locale.LC_TIME)
     try:
-        locale.setlocale(locale.LC_TIME, 'C')
-        report_time = time.mktime(time.strptime(report['Date']))
-    except KeyError:
+        try:
+            locale.setlocale(locale.LC_TIME, 'C')
+            report_time = time.mktime(time.strptime(report['Date']))
+        except KeyError:
+            return None
+        finally:
+            locale.setlocale(locale.LC_TIME, orig_ctime)
+    except locale.Error:
         return None
-    finally:
-        locale.setlocale(locale.LC_TIME, orig_ctime)
 
+    # determine cgroup
     try:
-        bus = Gio.bus_get_sync(Gio.BusType.SYSTEM, None)
-        ck_manager = Gio.DBusProxy.new_sync(
-            bus, Gio.DBusProxyFlags.NONE, None,
-            'org.freedesktop.ConsoleKit', '/org/freedesktop/ConsoleKit/Manager',
-            'org.freedesktop.ConsoleKit.Manager', None)
-
-        cur_session = ck_manager.GetCurrentSession()
-
-        ck_session = Gio.DBusProxy.new_sync(
-            bus, Gio.DBusProxyFlags.NONE, None,
-            'org.freedesktop.ConsoleKit', cur_session,
-            'org.freedesktop.ConsoleKit.Session', None)
-
-        session_start_time = ck_session.GetCreationTime()
-    except GLib.GError as e:
-        sys.stderr.write('Error connecting to ConsoleKit: %s\n' % str(e))
+        with open('/proc/self/cgroup') as f:
+            for l in f:
+                if 'name=systemd:' in l:
+                    my_cgroup = l.split('systemd:', 1)[1].strip()
+                    break
+            else:
+                return None
+    except IOError:
         return None
 
-    m = re.match('(\d{4}-\d\d-\d\dT\d\d:\d\d:\d\d)(?:\.\d+Z)$', session_start_time)
-    if m:
-        # CK gives UTC time
-        session_start_time = calendar.timegm(time.strptime(m.group(1), '%Y-%m-%dT%H:%M:%S'))
-    else:
-        sys.stderr.write('cannot parse time returned by CK: %s\n' % session_start_time)
-        return None
+    # determine cgroup creation time
+    session_start_time = os.stat('/sys/fs/cgroup/systemd/' + my_cgroup).st_mtime
 
     return session_start_time <= report_time
 
