@@ -268,8 +268,7 @@ class PackageInfo:
                 self._os_version = (name, version)
                 return self._os_version
             else:
-                sys.stderr.write('invalid /etc/os-release: Does not contain NAMe and VERSION_ID\n')
-                sys.exit(1)
+                sys.stderr.write('invalid /etc/os-release: Does not contain NAME and VERSION_ID\n')
 
         # fall back to lsb_release
         p = subprocess.Popen(['lsb_release', '-sir'], stdout=subprocess.PIPE,
