@@ -9,8 +9,8 @@
 # option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
 # the full text of the license.
 
-import subprocess, tempfile, os.path, re, pwd, grp, os
-import fnmatch, glob, traceback, errno, sys, atexit
+import subprocess, tempfile, os.path, re, pwd, grp, os, time
+import fnmatch, glob, traceback, errno, sys, atexit, locale
 
 import xml.dom, xml.dom.minidom
 from xml.parsers.expat import ExpatError
@@ -490,6 +490,9 @@ class Report(problem_report.ProblemReport):
         - ProcStatus: /proc/pid/status contents
         - ProcMaps: /proc/pid/maps contents
         - ProcAttrCurrent: /proc/pid/attr/current contents, if not "unconfined"
+        - CurrentDesktop: Value of $XDG_CURRENT_DESKTOP, if present
+        - _LogindSession: logind cgroup path, if present (Used for filtering
+          out crashes that happened in a session that is not running any more)
         '''
         if not pid:
             pid = self.pid or os.getpid()
@@ -540,6 +543,10 @@ class Report(problem_report.ProblemReport):
         except (IOError, OSError):
             pass
 
+        ret = self.get_logind_session(pid)
+        if ret:
+            self['_LogindSession'] = ret[0]
+
     def add_proc_environ(self, pid=None, extraenv=[]):
         '''Add environment information.
 
@@ -549,6 +556,7 @@ class Report(problem_report.ProblemReport):
         - ProcEnviron: A subset of the process' environment (only some standard
           variables that do not disclose potentially sensitive information, plus
           the ones mentioned in extraenv)
+        - CurrentDesktop: Value of $XDG_CURRENT_DESKTOP, if present
         '''
         safe_vars = ['SHELL', 'TERM', 'LANGUAGE', 'LANG', 'LC_CTYPE',
                      'LC_COLLATE', 'LC_TIME', 'LC_NUMERIC', 'LC_MONETARY',
@@ -581,17 +589,19 @@ class Report(problem_report.ProblemReport):
                             self['ProcEnviron'] += '\n'
                         self['ProcEnviron'] += 'PATH=(custom, no user)'
                 elif l.startswith('XDG_RUNTIME_DIR='):
-                        if self['ProcEnviron']:
-                            self['ProcEnviron'] += '\n'
-                        self['ProcEnviron'] += 'XDG_RUNTIME_DIR=<set>'
+                    if self['ProcEnviron']:
+                        self['ProcEnviron'] += '\n'
+                    self['ProcEnviron'] += 'XDG_RUNTIME_DIR=<set>'
                 elif l.startswith('LD_PRELOAD='):
-                        if self['ProcEnviron']:
-                            self['ProcEnviron'] += '\n'
-                        self['ProcEnviron'] += 'LD_PRELOAD=<set>'
+                    if self['ProcEnviron']:
+                        self['ProcEnviron'] += '\n'
+                    self['ProcEnviron'] += 'LD_PRELOAD=<set>'
                 elif l.startswith('LD_LIBRARY_PATH='):
-                        if self['ProcEnviron']:
-                            self['ProcEnviron'] += '\n'
-                        self['ProcEnviron'] += 'LD_LIBRARY_PATH=<set>'
+                    if self['ProcEnviron']:
+                        self['ProcEnviron'] += '\n'
+                    self['ProcEnviron'] += 'LD_LIBRARY_PATH=<set>'
+                elif l.startswith('XDG_CURRENT_DESKTOP='):
+                    self['CurrentDesktop'] = l.split('=', 1)[1]
 
     def add_kernel_crash_info(self, debugdir=None):
         '''Add information from kernel crash.
@@ -1463,13 +1473,18 @@ class Report(problem_report.ProblemReport):
 
         command = ['gdb']
 
-        if self.get('Architecture') != packaging.get_system_architecture():
+        if 'Architecture' in self and self['Architecture'] != packaging.get_system_architecture():
             # check if we have gdb-multiarch
             which = subprocess.Popen(['which', 'gdb-multiarch'],
                                      stdout=subprocess.PIPE)
             which.communicate()
             if which.returncode == 0:
                 command = ['gdb-multiarch']
+            else:
+                sys.stderr.write(
+                    'WARNING: Please install gdb-multiarch for processing '
+                    'reports from foreign architectures. Results with "gdb" '
+                    'will be very poor.\n')
 
             # check for foreign architecture
             arch = self.get('Uname', 'none').split()[-1]
@@ -1560,3 +1575,46 @@ class Report(problem_report.ProblemReport):
                 assert m, 'cannot parse ProcMaps line: ' + line
             self._proc_maps_cache.append((int(m.group(1), 16),
                                           int(m.group(2), 16), m.group(3)))
+
+    @classmethod
+    def get_logind_session(klass, pid):
+        '''Get logind session path and start time.
+
+        Return (path, session_start_timestamp) if pid is in a logind session,
+        or None otherwise.
+        '''
+        # determine cgroup
+        try:
+            with open('/proc/%s/cgroup' % pid) as f:
+                for l in f:
+                    if 'name=systemd:' in l:
+                        my_cgroup = l.split('systemd:', 1)[1].strip()
+                        if len(my_cgroup) < 2:
+                            return None
+                        break
+                else:
+                    return None
+            # determine cgroup creation time
+            session_start_time = os.stat('/sys/fs/cgroup/systemd/' + my_cgroup).st_mtime
+        except (IOError, OSError):
+            return None
+
+        return (my_cgroup, session_start_time)
+
+    def get_timestamp(self):
+        '''Get timestamp (seconds since epoch) from Date field
+
+        Return None if it is not present.
+        '''
+        # report time is from asctime(), not in locale representation
+        orig_ctime = locale.getlocale(locale.LC_TIME)
+        try:
+            try:
+                locale.setlocale(locale.LC_TIME, 'C')
+                return time.mktime(time.strptime(self['Date']))
+            except KeyError:
+                return None
+            finally:
+                locale.setlocale(locale.LC_TIME, orig_ctime)
+        except locale.Error:
+            return None
